@@ -6,11 +6,12 @@ describe 'basic gnocchi' do
 
     it 'should work with no errors' do
       pp = <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
-      class { '::openstack_integration::gnocchi':
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::apache
+      include openstack_integration::mysql
+      include openstack_integration::keystone
+      class { 'openstack_integration::gnocchi':
         integration_enable => false,
       }
       EOS
